@@ -10,8 +10,9 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
-"""Placeholder docstring"""
+"""Classes for using MXNet with Amazon SageMaker."""
 from __future__ import absolute_import  # noqa: F401
 
 from sagemaker.mxnet.estimator import MXNet  # noqa: F401
 from sagemaker.mxnet.model import MXNetModel, MXNetPredictor  # noqa: F401
+from sagemaker.mxnet.processing import MXNetProcessor  # noqa: F401
