@@ -18,7 +18,6 @@ from typing import List, Union, Optional
 
 import attr
 
-from sagemaker.deprecations import deprecated_class
 from sagemaker.estimator import EstimatorBase
 from sagemaker.model import Model
 from sagemaker import PipelineModel
@@ -63,8 +62,8 @@ class RegisterModel(StepCollection):  # pragma: no cover
         name: str,
         content_types,
         response_types,
-        inference_instances,
-        transform_instances,
+        inference_instances=None,
+        transform_instances=None,
         estimator: EstimatorBase = None,
         model_data=None,
         depends_on: Optional[List[Union[str, Step, StepCollection]]] = None,
@@ -220,9 +219,15 @@ class RegisterModel(StepCollection):  # pragma: no cover
                     kwargs.pop("output_kms_key", None)
 
             if isinstance(model, PipelineModel):
-                self.container_def_list = model.pipeline_container_def(inference_instances[0])
+                self.container_def_list = model.pipeline_container_def(
+                    inference_instances[0] if inference_instances else None
+                )
             elif isinstance(model, Model):
-                self.container_def_list = [model.prepare_container_def(inference_instances[0])]
+                self.container_def_list = [
+                    model.prepare_container_def(
+                        inference_instances[0] if inference_instances else None
+                    )
+                ]
 
         register_model_step = _RegisterModelStep(
             name=name,
@@ -256,8 +261,7 @@ class RegisterModel(StepCollection):  # pragma: no cover
         warnings.warn(
             (
                 "We are deprecating the use of RegisterModel. "
-                "Instead, please use the ModelStep, which simply takes in the step arguments "
-                "generated by model.register(). For more, see: "
+                "Please use the ModelStep instead. For more, see: "
                 "https://sagemaker.readthedocs.io/en/stable/"
                 "amazon_sagemaker_model_building_pipeline.html#model-step"
             ),
@@ -265,9 +269,6 @@ class RegisterModel(StepCollection):  # pragma: no cover
         )
 
 
-RegisterModel = deprecated_class(RegisterModel, "RegisterModel")
-
-
 class EstimatorTransformer(StepCollection):
     """Creates a Transformer step collection for workflow."""
 
