@@ -17,11 +17,12 @@ import abc
 import warnings
 
 from enum import Enum
-from typing import Dict, List, Union, Optional
+from typing import Dict, List, Union, Optional, TYPE_CHECKING
 from urllib.parse import urlparse
 
 import attr
 
+from sagemaker import Session
 from sagemaker.estimator import EstimatorBase, _TrainingJob
 from sagemaker.inputs import CreateModelInput, TrainingInput, TransformInput, FileSystemInput
 from sagemaker.model import Model
@@ -34,11 +35,13 @@ from sagemaker.processing import (
 )
 from sagemaker.transformer import Transformer, _TransformJob
 from sagemaker.tuner import HyperparameterTuner, _TuningJob
+from sagemaker.workflow import is_pipeline_variable
 from sagemaker.workflow.entities import (
     DefaultEnumMeta,
     Entity,
     RequestType,
 )
+from sagemaker.workflow.pipeline_context import _JobStepArguments
 from sagemaker.workflow.properties import (
     PropertyFile,
     Properties,
@@ -46,6 +49,9 @@ from sagemaker.workflow.properties import (
 from sagemaker.workflow.functions import Join
 from sagemaker.workflow.retry import RetryPolicy
 
+if TYPE_CHECKING:
+    from sagemaker.workflow.step_collections import StepCollection
+
 
 class StepTypeEnum(Enum, metaclass=DefaultEnumMeta):
     """Enum of `Step` types."""
@@ -74,15 +80,16 @@ class Step(Entity):
         display_name (str): The display name of the `Step`.
         description (str): The description of the `Step`.
         step_type (StepTypeEnum): The type of the `Step`.
-        depends_on (List[str] or List[Step]): The list of `Step` names or `Step`
-            instances that the current `Step` depends on.
+        depends_on (List[Union[str, Step, StepCollection]]): The list of `Step`/`StepCollection`
+            names or `Step` instances or `StepCollection` instances that the current `Step`
+            depends on.
     """
 
     name: str = attr.ib(factory=str)
-    display_name: str = attr.ib(default=None)
-    description: str = attr.ib(default=None)
+    display_name: Optional[str] = attr.ib(default=None)
+    description: Optional[str] = attr.ib(default=None)
     step_type: StepTypeEnum = attr.ib(factory=StepTypeEnum.factory)
-    depends_on: Union[List[str], List["Step"]] = attr.ib(default=None)
+    depends_on: Optional[List[Union[str, "Step", "StepCollection"]]] = attr.ib(default=None)
 
     @property
     @abc.abstractmethod
@@ -110,7 +117,7 @@ class Step(Entity):
 
         return request_dict
 
-    def add_depends_on(self, step_names: Union[List[str], List["Step"]]):
+    def add_depends_on(self, step_names: List[Union[str, "Step", "StepCollection"]]):
         """Add `Step` names or `Step` instances to the current `Step` depends on list."""
 
         if not step_names:
@@ -126,11 +133,17 @@ class Step(Entity):
         return {"Name": self.name}
 
     @staticmethod
-    def _resolve_depends_on(depends_on_list: Union[List[str], List["Step"]]) -> List[str]:
+    def _resolve_depends_on(
+        depends_on_list: List[Union[str, "Step", "StepCollection"]]
+    ) -> List[str]:
         """Resolve the `Step` depends on list."""
+        from sagemaker.workflow.step_collections import StepCollection
+
         depends_on = []
         for step in depends_on_list:
-            if isinstance(step, Step):
+            # As for StepCollection, the names of its sub steps will be interpolated
+            # when generating the pipeline definition
+            if isinstance(step, (Step, StepCollection)):
                 depends_on.append(step.name)
             elif isinstance(step, str):
                 depends_on.append(step)
@@ -187,7 +200,7 @@ class ConfigurableRetryStep(Step):
         step_type: StepTypeEnum,
         display_name: str = None,
         description: str = None,
-        depends_on: Union[List[str], List[Step]] = None,
+        depends_on: Optional[List[Union[str, Step, "StepCollection"]]] = None,
         retry_policies: List[RetryPolicy] = None,
     ):
         super().__init__(
@@ -227,13 +240,13 @@ class TrainingStep(ConfigurableRetryStep):
     def __init__(
         self,
         name: str,
-        step_args: Dict = None,
+        step_args: _JobStepArguments = None,
         estimator: EstimatorBase = None,
         display_name: str = None,
         description: str = None,
         inputs: Union[TrainingInput, dict, str, FileSystemInput] = None,
         cache_config: CacheConfig = None,
-        depends_on: Union[List[str], List[Step]] = None,
+        depends_on: Optional[List[Union[str, Step, "StepCollection"]]] = None,
         retry_policies: List[RetryPolicy] = None,
     ):
         """Construct a `TrainingStep`, given an `EstimatorBase` instance.
@@ -243,7 +256,7 @@ class TrainingStep(ConfigurableRetryStep):
 
         Args:
             name (str): The name of the `TrainingStep`.
-            step_args: The arguments for the `TrainingStep` definition.
+            step_args (_JobStepArguments): The arguments for the `TrainingStep` definition.
             estimator (EstimatorBase): A `sagemaker.estimator.EstimatorBase` instance.
             display_name (str): The display name of the `TrainingStep`.
             description (str): The description of the `TrainingStep`.
@@ -264,8 +277,9 @@ class TrainingStep(ConfigurableRetryStep):
                   the path to the training dataset.
 
             cache_config (CacheConfig):  A `sagemaker.workflow.steps.CacheConfig` instance.
-            depends_on (List[str] or List[Step]): A list of `Step` names or `Step` instances
-                this `sagemaker.workflow.steps.TrainingStep` depends on.
+            depends_on (List[Union[str, Step, StepCollection]]): A list of `Step`/`StepCollection`
+                names or `Step` instances or `StepCollection` instances that this `TrainingStep`
+                depends on.
             retry_policies (List[RetryPolicy]):  A list of retry policies.
         """
         super(TrainingStep, self).__init__(
@@ -273,9 +287,18 @@ class TrainingStep(ConfigurableRetryStep):
         )
 
         if not (step_args is not None) ^ (estimator is not None):
-            raise ValueError("either step_args or estimator need to be given.")
+            raise ValueError("Either step_args or estimator need to be given.")
 
-        self.step_args = step_args
+        if step_args:
+            from sagemaker.workflow.utilities import validate_step_args_input
+
+            validate_step_args_input(
+                step_args=step_args,
+                expected_caller={Session.train.__name__},
+                error_message="The step_args of TrainingStep must be obtained from estimator.fit().",
+            )
+
+        self.step_args = step_args.args if step_args else None
         self.estimator = estimator
         self.inputs = inputs
 
@@ -383,7 +406,7 @@ class CreateModelStep(ConfigurableRetryStep):
         step_args: Optional[dict] = None,
         model: Optional[Union[Model, PipelineModel]] = None,
         inputs: Optional[CreateModelInput] = None,
-        depends_on: Optional[Union[List[str], List[Step]]] = None,
+        depends_on: Optional[List[Union[str, Step, "StepCollection"]]] = None,
         retry_policies: Optional[List[RetryPolicy]] = None,
         display_name: Optional[str] = None,
         description: Optional[str] = None,
@@ -400,8 +423,9 @@ class CreateModelStep(ConfigurableRetryStep):
                 or `sagemaker.pipeline.PipelineModel` instance (default: None).
             inputs (CreateModelInput): A `sagemaker.inputs.CreateModelInput` instance.
                 (default: None).
-            depends_on (List[str] or List[Step]): A list of `Step` names or `Step` instances
-                this `sagemaker.workflow.steps.CreateModelStep` depends on (default: None).
+            depends_on (List[Union[str, Step, StepCollection]]): A list of `Step`/`StepCollection`
+                names or `Step` instances or `StepCollection` instances that this `CreateModelStep`
+                depends on (default: None).
             retry_policies (List[RetryPolicy]):  A list of retry policies (default: None).
             display_name (str): The display name of the `CreateModelStep` (default: None).
             description (str): The description of the `CreateModelStep` (default: None).
@@ -420,12 +444,13 @@ class CreateModelStep(ConfigurableRetryStep):
 
         self._properties = Properties(path=f"Steps.{name}", shape_name="DescribeModelOutput")
 
-        # TODO: add public document link here once ready
         warnings.warn(
             (
                 "We are deprecating the use of CreateModelStep. "
                 "Instead, please use the ModelStep, which simply takes in the step arguments "
-                "generated by model.create()."
+                "generated by model.create(). For more, see: "
+                "https://sagemaker.readthedocs.io/en/stable/"
+                "amazon_sagemaker_model_building_pipeline.html#model-step"
             ),
             DeprecationWarning,
         )
@@ -476,13 +501,13 @@ class TransformStep(ConfigurableRetryStep):
     def __init__(
         self,
         name: str,
-        step_args: Dict = None,
+        step_args: _JobStepArguments = None,
         transformer: Transformer = None,
         inputs: TransformInput = None,
         display_name: str = None,
         description: str = None,
         cache_config: CacheConfig = None,
-        depends_on: Union[List[str], List[Step]] = None,
+        depends_on: Optional[List[Union[str, Step, "StepCollection"]]] = None,
         retry_policies: List[RetryPolicy] = None,
     ):
         """Constructs a `TransformStep`, given a `Transformer` instance.
@@ -492,13 +517,14 @@ class TransformStep(ConfigurableRetryStep):
 
         Args:
             name (str): The name of the `TransformStep`.
-            step_args: The arguments for the `TransformStep` definition.
+            step_args (_JobStepArguments): The arguments for the `TransformStep` definition.
             transformer (Transformer): A `sagemaker.transformer.Transformer` instance.
             inputs (TransformInput): A `sagemaker.inputs.TransformInput` instance.
             cache_config (CacheConfig): A `sagemaker.workflow.steps.CacheConfig` instance.
             display_name (str): The display name of the `TransformStep`.
             description (str): The description of the `TransformStep`.
-            depends_on (List[str]): A list of `Step` names that this `sagemaker.workflow.steps.TransformStep`
+            depends_on (List[Union[str, Step, StepCollection]]): A list of `Step`/`StepCollection`
+                names or `Step` instances or `StepCollection` instances that this `TransformStep`
                 depends on.
             retry_policies (List[RetryPolicy]): A list of retry policies.
         """
@@ -509,7 +535,17 @@ class TransformStep(ConfigurableRetryStep):
         if not (step_args is not None) ^ (transformer is not None):
             raise ValueError("either step_args or transformer need to be given, but not both.")
 
-        self.step_args = step_args
+        if step_args:
+            from sagemaker.workflow.utilities import validate_step_args_input
+
+            validate_step_args_input(
+                step_args=step_args,
+                expected_caller={Session.transform.__name__},
+                error_message="The step_args of TransformStep must be obtained "
+                "from transformer.transform().",
+            )
+
+        self.step_args = step_args.args if step_args else None
         self.transformer = transformer
         self.inputs = inputs
         self.cache_config = cache_config
@@ -579,7 +615,7 @@ class ProcessingStep(ConfigurableRetryStep):
     def __init__(
         self,
         name: str,
-        step_args: Dict = None,
+        step_args: _JobStepArguments = None,
         processor: Processor = None,
         display_name: str = None,
         description: str = None,
@@ -589,7 +625,7 @@ class ProcessingStep(ConfigurableRetryStep):
         code: str = None,
         property_files: List[PropertyFile] = None,
         cache_config: CacheConfig = None,
-        depends_on: Union[List[str], List[Step]] = None,
+        depends_on: Optional[List[Union[str, Step, "StepCollection"]]] = None,
         retry_policies: List[RetryPolicy] = None,
         kms_key=None,
     ):
@@ -600,7 +636,7 @@ class ProcessingStep(ConfigurableRetryStep):
 
         Args:
             name (str): The name of the `ProcessingStep`.
-            step_args: The arguments for the `ProcessingStep` definition.
+            step_args (_JobStepArguments): The arguments for the `ProcessingStep` definition.
             processor (Processor): A `sagemaker.processing.Processor` instance.
             display_name (str): The display name of the `ProcessingStep`.
             description (str): The description of the `ProcessingStep`
@@ -615,8 +651,9 @@ class ProcessingStep(ConfigurableRetryStep):
             property_files (List[PropertyFile]): A list of property files that workflow looks
                 for and resolves from the configured processing output list.
             cache_config (CacheConfig):  A `sagemaker.workflow.steps.CacheConfig` instance.
-            depends_on (List[str] or List[Step]): A list of `Step` names or `Step` instances that
-                this `sagemaker.workflow.steps.ProcessingStep` depends on.
+            depends_on (List[Union[str, Step, StepCollection]]): A list of `Step`/`StepCollection`
+                names or `Step` instances or `StepCollection` instances that this `ProcessingStep`
+                depends on.
             retry_policies (List[RetryPolicy]):  A list of retry policies.
             kms_key (str): The ARN of the KMS key that is used to encrypt the
                 user code file. Defaults to `None`.
@@ -628,7 +665,16 @@ class ProcessingStep(ConfigurableRetryStep):
         if not (step_args is not None) ^ (processor is not None):
             raise ValueError("either step_args or processor need to be given, but not both.")
 
-        self.step_args = step_args
+        if step_args:
+            from sagemaker.workflow.utilities import validate_step_args_input
+
+            validate_step_args_input(
+                step_args=step_args,
+                expected_caller={Session.process.__name__},
+                error_message="The step_args of ProcessingStep must be obtained from processor.run().",
+            )
+
+        self.step_args = step_args.args if step_args else None
         self.processor = processor
         self.inputs = inputs
         self.outputs = outputs
@@ -649,6 +695,11 @@ class ProcessingStep(ConfigurableRetryStep):
             self.processor.arguments = job_arguments
 
             if code:
+                if is_pipeline_variable(code):
+                    raise ValueError(
+                        "code argument has to be a valid S3 URI or local file path "
+                        + "rather than a pipeline variable"
+                    )
                 code_url = urlparse(code)
                 if code_url.scheme == "" or code_url.scheme == "file":
                     # By default, `Processor` will upload the local code to an S3 path
@@ -724,14 +775,14 @@ class TuningStep(ConfigurableRetryStep):
     def __init__(
         self,
         name: str,
-        step_args: Dict = None,
+        step_args: _JobStepArguments = None,
         tuner: HyperparameterTuner = None,
         display_name: str = None,
         description: str = None,
         inputs=None,
         job_arguments: List[str] = None,
         cache_config: CacheConfig = None,
-        depends_on: Union[List[str], List[Step]] = None,
+        depends_on: Optional[List[Union[str, Step, "StepCollection"]]] = None,
         retry_policies: List[RetryPolicy] = None,
     ):
         """Construct a `TuningStep`, given a `HyperparameterTuner` instance.
@@ -741,7 +792,7 @@ class TuningStep(ConfigurableRetryStep):
 
         Args:
             name (str): The name of the `TuningStep`.
-            step_args: The arguments for the `TuningStep` definition.
+            step_args (_JobStepArguments): The arguments for the `TuningStep` definition.
             tuner (HyperparameterTuner): A `sagemaker.tuner.HyperparameterTuner` instance.
             display_name (str): The display name of the `TuningStep`.
             description (str): The description of the `TuningStep`.
@@ -775,8 +826,9 @@ class TuningStep(ConfigurableRetryStep):
             job_arguments (List[str]): A list of strings to be passed into the processing job.
                 Defaults to `None`.
             cache_config (CacheConfig):  A `sagemaker.workflow.steps.CacheConfig` instance.
-            depends_on (List[str] or List[Step]): A list of `Step` names or `Step` instances that
-                this `sagemaker.workflow.steps.ProcessingStep` depends on.
+            depends_on (List[Union[str, Step, StepCollection]]): A list of `Step`/`StepCollection`
+                names or `Step` instances or `StepCollection` instances that this `TuningStep`
+                depends on.
             retry_policies (List[RetryPolicy]):  A list of retry policies.
         """
         super(TuningStep, self).__init__(
@@ -786,7 +838,16 @@ class TuningStep(ConfigurableRetryStep):
         if not (step_args is not None) ^ (tuner is not None):
             raise ValueError("either step_args or tuner need to be given, but not both.")
 
-        self.step_args = step_args
+        if step_args:
+            from sagemaker.workflow.utilities import validate_step_args_input
+
+            validate_step_args_input(
+                step_args=step_args,
+                expected_caller={Session.create_tuning_job.__name__},
+                error_message="The step_args of TuningStep must be obtained from tuner.fit().",
+            )
+
+        self.step_args = step_args.args if step_args else None
         self.tuner = tuner
         self.inputs = inputs
         self.job_arguments = job_arguments
